Update of /cvsroot/monetdb/pathfinder/compiler/mil
In directory sc8-pr-cvs16.sourceforge.net:/tmp/cvs-serv19263/compiler/mil

Modified Files:
        mil_opt.c milprint_summer.c 
Log Message:
propagated changes of Monday Jul 09 2007 - Tuesday Jul 24 2007
from the XQuery_0-18 branch to the development trunk



Index: milprint_summer.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/mil/milprint_summer.c,v
retrieving revision 1.399
retrieving revision 1.400
diff -u -d -r1.399 -r1.400
--- milprint_summer.c   23 Jul 2007 16:17:21 -0000      1.399
+++ milprint_summer.c   24 Jul 2007 16:42:09 -0000      1.400
@@ -4689,7 +4689,7 @@
             "var iter_grp  := iter.materialize(ipik);\n"
             "iter := iter_grp.tunique();\n"
             "var iter_aggr := {%s}(item%s.materialize(ipik), iter_grp, 
iter).tmark([EMAIL PROTECTED]);\n"
-            "iter := iter.hmark([EMAIL PROTECTED]);\n"
+            "iter := iter.hmark([EMAIL PROTECTED]).chk_order();\n"
             "ipik := iter;\n"
             "pos := [EMAIL PROTECTED];\n"
             "kind := %s;\n",


-------------------------------------------------------------------------
This SF.net email is sponsored by: Splunk Inc.
Still grepping through log files to find problems?  Stop.
Now Search log events and configuration files using AJAX and a browser.
Download your FREE copy of Splunk now >>  http://get.splunk.com/
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins

Reply via email to
Index: mil_opt.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/mil/mil_opt.c,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -d -r1.29 -r1.30
--- mil_opt.c   6 Jun 2007 20:19:27 -0000       1.29
+++ mil_opt.c   24 Jul 2007 16:42:09 -0000      1.30
@@ -536,7 +536,7 @@
  */
 static void opt_assign(opt_t *o, opt_name_t *name, unsigned int stmt) {
        int i = opt_findvar(o, name);
-       /* we may only prune if the variable being overwritten comes from a 
unconditional scope */
+       /* we may only prune if the variable being overwritten comes from an 
unconditional scope */
        if (i >= 0) {
                unsigned int def_stmt = o->vars[i].def_stmt;
                unsigned int cond = OPT_COND(o);
@@ -576,8 +576,12 @@
                        opt_move_add(o, stmt); /* register this statement as 
moveable */
 #endif
                }
-       } else {
-               /* delete this statement */
+       } else if (o->curvar+1 < OPT_VARS) {
+               /* delete this statement (but only if there was no
+                  variable overflow, but note that we can't actually
+                  see whether there was overflow, we can only see
+                  whether the table is full, so we assume that there
+                  was overflow when the table is full) */
                o->stmts[stmt].deleted = o->delete;
        }
 }
